--DropDownHandlers

--
-- Set up and handle the Drop downs in the help menu
--
function WC.Spell_DropDownHandler_OnShow()
	local dd = this; --the current menu calling the onshow event
	
	UIDropDownMenu_Initialize( dd, WC.Spell_DropDownHandler_Initialize );
	local ddMenuName = dd:GetName();
	local menuItem, thing = W.Get_Saved_MenuItem( ddMenuName ); --retrieve the saved spell for this drop down
	
	if ( menuItem == W_kMenuRunMacro ) then
		menuItem = thing;
	elseif ( menuItem == W_kMenuCustomList ) then --the custom list stores stuff in rows of tables  thingName, thingType (item, spell or macro)
		if ( thing ) then --make sure thing is valid
			local thingTable = thing;
			local thingName = thingTable[1];
			local thingType = thingTable[2];
			menuItem = thingName
		else --it was not valid, so just use empty in the drop down
			menuItem = "Empty";
		end
	end
	
	UIDropDownMenu_SetText( menuItem, dd);
	UIDropDownMenu_SetWidth( 150, dd );
end

function WC.Spell_DropDownHandler_Initialize()
	local dd = getglobal( UIDROPDOWNMENU_OPEN_MENU );
	local selectedText = UIDropDownMenu_GetText( dd ); --get the option that is selected in the dropdown

	if ( UIDROPDOWNMENU_MENU_LEVEL == 1 ) then -- are we initting main menus
		local index, menuItem;
		local charType = W.GetCharClass("player");
		local tableName = ("W_"..charType.."SpellTable"); --figure out which table to use based on char type
		local t = getglobal(tableName); -- a reference to the table
		local func = function() WC.Spell_DropDownHandler_OnClick( dd ) end; --the function to be called when a dropdown item is selected

		for index, menuItem in pairs( t ) do --iterate over the key, values pairs from the spell table for this char
			info = UIDropDownMenu_CreateInfo();

			if ( type(menuItem) == "table" ) then --if this menu item is a table, then add the sub menu arrow
				info.text = menuItem[1]; --the first item in the sub table is the name we want displayed in the mail menu
				info.value = menuItem; --keep track of the subtable that the sub values are in so we can show them when the user selects it
				info.func = nil; --since this is a sub table, there is no function
				info.hasArrow = 1; --it does have an arrow since it is a sub menu
			elseif ( menuItem == W_kMenuRunMacro ) then
				info.text = W_kMenuRunMacro; --the first item in the sub table is the name we want displayed in the mail menu
				info.value = W_kMenuRunMacro; --keep track of the subtable that the sub values are in so we can show them when the user selects it
				info.func = nil; --since this is a sub table, there is no function
				info.hasArrow = 1; --it does have an arrow since it is a sub menu
			elseif ( menuItem == W_kMenuCustomList ) then
				info.text = W_kMenuCustomList;
				info.value = W_kMenuCustomList;
				info.func = nil
				info.hasArrow = 1;
			else --it was not a table or a macro, so add it as a regular menu item
				info.text =  menuItem; --the text to show in the menu
				info.value = menuItem; --the value ( the index ) of the item
				info.func = func; --the function to call when the item is selected
				info.checked = (menuItem == selectedText) --if this is the item that is selected, then check it
			end
			UIDropDownMenu_AddButton( info, 1 );
		end
	elseif ( UIDROPDOWNMENU_MENU_LEVEL == 2 ) then -- are we initting sub menus
		local menuItem = UIDROPDOWNMENU_MENU_VALUE; --the value for this is set above in info.value=menuitem, where menuitem is a table or W_kMenuRunMacro
		
		if ( menuItem == W_kMenuRunMacro ) then
			local func = function() WC.Macro_DropDownHandler_OnClick( dd ) end; --the function to call when a sub menu item is selected
			local numGlobal, numPerChar = GetNumMacros(); --get the total number of macros total and for this char
			for macroNum = 1,numGlobal do
				local macroName, texture, macrobody, localVar = GetMacroInfo(macroNum)
				local info = UIDropDownMenu_CreateInfo();
				
				info.text = macroName;
				info.value = macroName;

				info.checked = ( macroName == selectedText ); --see which was selected before ( W_DropDownList1,2etc )
				info.func = func;
				UIDropDownMenu_AddButton(info, UIDROPDOWNMENU_MENU_LEVEL)
			end
		elseif ( menuItem == W_kMenuCustomList ) then
			local func = function() WC.CustomList_DropDownHandler_OnClick( dd ) end; --the function to call when a sub menu item is selected
			for index, subMenuItem in pairs( W_gCustomList ) do --iterate over the key, value pairs and populate the sub menu from the custom list
				local thingTable = subMenuItem; --the items in the list are itemname and type, which is item, spell or macro
				local thingName = thingTable[1];
				local thingType = thingTable[2];
				info = UIDropDownMenu_CreateInfo();
				info.text = thingName;
				info.value = thingTable;
				info.func = func;
				info.checked = ( thingName == selectedText ); --is this the option that is selected in the drop down?
				UIDropDownMenu_AddButton(info, UIDROPDOWNMENU_MENU_LEVEL)
			end
		
		elseif ( type(menuItem) == "table" ) then --if the value a table? If so, then populate the sub menu or it's the custom list
			local subMenuName = menuItem[1]; --the first item in the sub menu table is the name
			local func = function() WC.Spell_DropDownHandler_OnClick( dd ) end; --the function to call when a sub menu item is selected
			for index, subMenuItem in pairs( menuItem ) do --iterate over the key, value pairs and populate the sub menu
				if ( index > 1 ) then --index=1 is the title used in the main menu. Don't need to add it to sub menu
					info = UIDropDownMenu_CreateInfo();
					info.text = subMenuItem;
					info.value = subMenuItem;
					info.func = func;
					info.checked = ( subMenuItem == selectedText ); --is this the option that is selected in the drop down?
					UIDropDownMenu_AddButton(info, UIDROPDOWNMENU_MENU_LEVEL)
				end
			end
		end
	end
end

function WC.Spell_DropDownHandler_OnClick( dd )
	local selectedText = this.value; --keep track of what we selected ( the text of it )
	local ddName = dd:GetName(); --get the name of the dropdown that is currently dropped down
	
	UIDropDownMenu_SetText(selectedText, dd); --set the frame text to the new selection
	W_gSavedSpells[ddName] = selectedText; --store the newly selected spell with this dropdown in the saved spells table
	W.Update_Unit_Buttons(); --update the unit buttons to reflect this new spell
	if ( UIDROPDOWNMENU_MENU_LEVEL == 2 ) then
		HideDropDownMenu(1); --hide the main drop down since we are done selecting something from the sub menu
	end
	if ( W_gDropDownCustomList[ddName] ) then --if this was previously set to a custom list, remove the entry from the table
		W_gDropDownCustomList[ddName] = nil;
	end
	if ( W_gSavedMacros[ddName] ) then --if this was previously set to a macro, remove the entry from the table
		W_gSavedMacros[ddName] = nil;
	end
end


function WC.Macro_DropDownHandler_OnClick( dd )
	local macroName = this.value; --keep track of what macro we selected ( the text of it )
	local ddName = dd:GetName();
	
	UIDropDownMenu_SetText(macroName, dd); --set the frame text to the new selection
	W_gSavedSpells[ ddName ] = W_kMenuRunMacro; --store the newly selected spell with this dropdown in the saved spells table
	W_gSavedMacros[ ddName ] = macroName; -- keep track of which Macro it is
	W.Update_Unit_Buttons(); --update the unit buttons to reflect this new spell
	if ( UIDROPDOWNMENU_MENU_LEVEL == 2 ) then
		HideDropDownMenu(1); --hide the main drop down since we are done selecting something from the sub menu
	end
	if ( W_gDropDownCustomList[ddName] ) then --if this was previously set to a custom list, remove the entry from the table
		W_gDropDownCustomList[ddName] = nil;
	end
end

function WC.CustomList_DropDownHandler_OnClick( dd )
	local ddName = dd:GetName();
	local thingTable = this.value;
	local thingName = thingTable[1];
	local thingType = thingTable[2];
		
	UIDropDownMenu_SetText(thingName, dd); --set the frame text to the new selection
	W_gSavedSpells[ ddName ] = W_kMenuCustomList;
	W_gDropDownCustomList[ ddName ] = thingTable;
	
	W.Update_Unit_Buttons();
	if ( UIDROPDOWNMENU_MENU_LEVEL == 2 ) then
		HideDropDownMenu(1); --hide the main drop down since we are done selecting something from the sub menu
	end
	if ( W_gSavedMacros[ddName] ) then --if this was previously set to a macro, remove the entry from the table
		W_gSavedMacros[ddName] = nil;
	end
end


--
-- Set up and Handle the Health Level drop down
--
function WC.Health_DropDownHandler_OnShow()
	local dd = getglobal("W_Health_DropDown");

	UIDropDownMenu_Initialize( this, WC.Health_DropDownHandler_Initialize);
	UIDropDownMenu_SetText( W_gHealthLevel, dd);--init to the saved var
	UIDropDownMenu_SetWidth( 50, dd );
end

function WC.Health_DropDownHandler_Initialize()
	local dd = getglobal("W_Health_DropDown");
	local selectedText = UIDropDownMenu_GetText( dd ); --get the option that is selected in the dropdown
	local index, menuItem;
	local t = {"Off","10","20","30","40","50","60","70","80","90"}; --table for the percentage health
	local func = function() WC.Health_DropDownHandler_OnClick() end; --the function to be called when a dropdown item is selected
	
	for index, menuItem in pairs( t ) do --iterate over the key, values pairs from the table
		info = UIDropDownMenu_CreateInfo();
		info.text =  menuItem; --the text to show in the menu
		info.value = menuItem; --the value ( the index ) of the item
		info.func = func; --the function to call when the item is selected
		info.checked = (menuItem == selectedText) --if this is the item that is selected, then check it
		UIDropDownMenu_AddButton( info, 1 ); --1 is the menu level
	end
end

function WC.Health_DropDownHandler_OnClick()
	local dd = getglobal("W_Health_DropDown");
	local dd2 = getglobal("W_Health2_DropDown");
	local selectedText = this.value; --keep track of what we selected ( the text of it )
	
	UIDropDownMenu_SetText(selectedText, dd); --set the frame text
	
	W_gHealthLevel = selectedText; --keep track of the new selection so it will be saved when we log
	
	if ( selectedText == "Off" ) then --if we select off in the first drop down, turn off the second one as well
		UIDropDownMenu_SetText(selectedText, dd2); --set the frame text of dd2 to be off as well
		UIDropDownMenu_DisableDropDown( dd2 );
	else
		UIDropDownMenu_EnableDropDown( dd2 );
	end
end

-- Health2 Drop Down
function WC.Health2_DropDownHandler_OnShow()
	local dd = getglobal("W_Health2_DropDown");

	UIDropDownMenu_Initialize( this, WC.Health2_DropDownHandler_Initialize);
	UIDropDownMenu_SetText( W_gHealthLevel2, dd);--init to the saved var
	UIDropDownMenu_SetWidth( 50, dd );
end

function WC.Health2_DropDownHandler_Initialize()
	local dd = getglobal("W_Health2_DropDown");
	local selectedText = UIDropDownMenu_GetText( dd ); --get the option that is selected in the dropdown
	local index, menuItem;
	local t = {"Off","10","20","30","40","50","60","70","80","90"}; --table for the percentage health
	local func = function() WC.Health2_DropDownHandler_OnClick() end; --the function to be called when a dropdown item is selected
	
	for index, menuItem in pairs( t ) do --iterate over the key, values pairs from the table
		info = UIDropDownMenu_CreateInfo();
		info.text =  menuItem; --the text to show in the menu
		info.value = menuItem; --the value ( the index ) of the item
		info.func = func; --the function to call when the item is selected
		info.checked = (menuItem == selectedText) --if this is the item that is selected, then check it
		UIDropDownMenu_AddButton( info, 1 ); --1 is the menu level
	end
end

function WC.Health2_DropDownHandler_OnClick()
	local dd = getglobal("W_Health2_DropDown");
	local selectedText = this.value; --keep track of what we selected ( the text of it )
	
	UIDropDownMenu_SetText(selectedText, dd); --set the frame text
	
	W_gHealthLevel2 = selectedText; --keep track of the new selection so it will be saved when we log
end



--
-- toggle the config frame shown and hidden
--
function WC.Config_Frame_Toggle()
	local configFrame = WhammyConfigFrame;
	local wFrame = WhammyFrame;
	local parentFrame = UIParent; --need to make sure we open the config frame in the work area
	local parentFrameWidth = parentFrame:GetWidth(); -- get the width of the main window
	local parentFrameHeight = parentFrame:GetHeight();
	local wFrameLeft 		= floor( wFrame:GetLeft() + 0.5 ); --get left and make it an integer
	local wFrameTop 		= floor( wFrame:GetTop() + 0.5 );
	local wFrameWidth 		= floor( wFrame:GetWidth() + 0.5 );
	local wFrameHeight 		= floor( wFrame:GetHeight() + 0.5 );
	local configFrameLeft 	= floor( configFrame:GetLeft() + 0.5 );
	local configFrameWidth 	= floor( configFrame:GetWidth() + 0.5 );
	local configFrameHeight = floor( configFrame:GetHeight() + 0.5 );
	local totalWidth = wFrameLeft + wFrameWidth + configFrameWidth; --the width of all the frames added together
	local configFrameBottom = wFrameTop - configFrameHeight; --the y axis is 0 at the bottom and goes up. Assume the config frame will be
															-- opening down (tops equal) to see if it will fit
	if ( configFrame ) then
		if ( configFrame:IsVisible() ) then --hide the frame if it's visible
			configFrame:Hide();
		else --show the frame if it's hidden

			configFrame:ClearAllPoints(); --releases the frame so it can be repositioned
			if ( totalWidth > parentFrameWidth ) then --if the config window is off the right side of the screen, open on the left of Whammy
				if ( configFrameBottom < 0 ) then --it would also be off the botom of the screen to open it upwards. note that y=0 is the bottom of the screen
					configFrame:SetPoint("BOTTOMRIGHT", wFrame, "BOTTOMLEFT", -5, 2);
				else --ok to open downwards
					configFrame:SetPoint("TOPRIGHT", wFrame, "TOPLEFT", -5, -5);
				end
			else -- it was not off the right side of the screen, so open it on the right
				if ( configFrameBottom < 0 ) then --it would also be off the bottom of the screen to open it upwards
					configFrame:SetPoint("BOTTOMLEFT", wFrame, "BOTTOMRIGHT", 5, 2);
				else
					configFrame:SetPoint("TOPLEFT", wFrame, "TOPRIGHT", 5, -5);
				end
			end
			
			configFrame:Show();
		end
	end
end

function WC.Config_Frame_OnLoad() --the inital position of the config frame is to the right of the WhammyFrame opening downward
	this:SetPoint("TOPLEFT", WhammyFrame, "TOPRIGHT", 5, -5);
	local wcf = 'WhammyConfigFrame';
	
	getglobal( wcf.."_Health_Text"):SetText( W_kConfigHealthAlertText );
	
	getglobal( wcf.."_Left_Text"):SetText( W_kLeftText );
	getglobal( wcf.."_Middle_Text"):SetText( W_kMiddleText );
	getglobal( wcf.."_Right_Text"):SetText( W_kRightText );
	
	getglobal( wcf.."_Ctrl_Left_Text"):SetText( W_kCtrl.." "..W_kLeftText );
	getglobal( wcf.."_Ctrl_Middle_Text"):SetText( W_kCtrl.." "..W_kMiddleText );
	getglobal( wcf.."_Ctrl_Right_Text"):SetText( W_kCtrl.." "..W_kRightText );
	
	getglobal( wcf.."_Shift_Left_Text"):SetText( W_kShift.." "..W_kLeftText );
	getglobal( wcf.."_Shift_Middle_Text"):SetText( W_kShift.." "..W_kMiddleText );
	getglobal( wcf.."_Shift_Right_Text"):SetText( W_kShift.." "..W_kRightText );
	
	getglobal( wcf.."_Alt_Left_Text"):SetText( W_kAlt.." "..W_kLeftText );
	getglobal( wcf.."_Alt_Middle_Text"):SetText( W_kAlt.." "..W_kMiddleText );
	getglobal( wcf.."_Alt_Right_Text"):SetText( W_kAlt.." "..W_kRightText );
	
end